AntialiasingOption

Enum AntialiasingOption 

#[non_exhaustive]
pub enum AntialiasingOption { None, IfCheap, Always, }
Choices for GraphicsOptions::antialiasing.

Serialization stability warning

This type implements [serde::Serialize] and [serde::Deserialize], but serialization support is still experimental (as is the game data model in general). We do not guarantee that future versions of all-is-cubes will be able to deserialize data which is serialized by this version.

Additionally, the serialization schema is designed with serde_json in mind. It is not guaranteed that using a different data format crate, which may use a different subset of the information exposed via [serde::Serialize], will produce stable results.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None

Do not apply antialiasing. Every pixel of the rendered image will be the exact color of some part of the world, rather than a combination of adjacent parts.



IfCheap

If multisample anti-aliasing or similar functionality is available, allowing relatively cheap antialiasing, then enable it.



Always

Always perform antialiasing, even if it is expensive.