ExposureOption

Enum ExposureOption 

#[non_exhaustive]
pub enum ExposureOption { Fixed(PositiveSign<f32>), Automatic, }
“Camera exposure” control: selection of algorithm to control the scaling factor from scene luminance to displayed luminance. Part of a GraphicsOptions.

Note that the exact interpretation of this value also depends on on the chosen ToneMappingOperator.

Serialization stability warning

This type implements [serde::Serialize] and [serde::Deserialize], but serialization support is still experimental (as is the game data model in general). We do not guarantee that future versions of all-is-cubes will be able to deserialize data which is serialized by this version.

Additionally, the serialization schema is designed with serde_json in mind. It is not guaranteed that using a different data format crate, which may use a different subset of the information exposed via [serde::Serialize], will produce stable results.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Fixed(PositiveSign<f32>)

Constant exposure; light values in the scene are multiplied by this value before the tone mapping operator is applied.



Automatic

Exposure adjusts to compensate for the actual brightness of the scene.

Note: If GraphicsOptions::lighting_display is disabled, then this currently will act as Fixed(1.0).