FogOption

Enum FogOption 

#[non_exhaustive]
pub enum FogOption { None, Abrupt, Compromise, Physical, }
Choices for GraphicsOptions::fog.

Serialization stability warning

This type implements [serde::Serialize] and [serde::Deserialize], but serialization support is still experimental (as is the game data model in general). We do not guarantee that future versions of all-is-cubes will be able to deserialize data which is serialized by this version.

Additionally, the serialization schema is designed with serde_json in mind. It is not guaranteed that using a different data format crate, which may use a different subset of the information exposed via [serde::Serialize], will produce stable results.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None

No fog: objects will maintain their color and disappear raggedly.



Abrupt

Fog starts just before the view distance ends.



Compromise

Compromise between Abrupt and Physical options.



Physical

Almost physically realistic fog of constant density.