Camera

Struct Camera 

pub struct Camera { /* private fields */ }

Implementations

Source

impl Camera

Basic creation and mutation.

pub fn new(options: GraphicsOptions, viewport: Viewport) -> Camera

Create a camera which has

  • options and viewport as given,
  • a view transform of ViewTransform::identity(), and
  • an exposure determined based on the graphics options.
pub fn set_options(&mut self, options: GraphicsOptions)

Replace the GraphicsOptions stored in this camera with options.repair().

pub fn options(&self) -> &GraphicsOptions

Returns the GraphicsOptions value last provided to Camera::new() or Camera::set_options() (possibly with adjusted values).

pub fn set_viewport(&mut self, viewport: Viewport)

Sets the contained viewport value, and recalculates matrices to be suitable for the new viewport’s aspect ratio.

pub fn viewport(&self) -> Viewport

Returns the viewport last provided to Camera::new() or Camera::set_viewport().

pub fn set_view_transform( &mut self, eye_to_world_transform: RigidTransform3D<f64, Eye, Cube>, )

Sets the view transform and recalculates matrices appropriately.

Note that this is specified as the eye-to-world transform; that is, the given transform’s translation should be equal to the view point in world coordinates.

Besides controlling rendering, this is used to determine world coordinates for purposes of view_position() and project_ndc_into_world().

pub fn look_at_y_up( &mut self, eye: Point3D<f64, Cube>, target: Point3D<f64, Cube>, )

Sets the view transform like Camera::set_view_transform(), but in “look at” fashion.

pub fn view_transform(&self) -> RigidTransform3D<f64, Eye, Cube>

Returns the last eye-to-world transform set by Camera::set_view_transform().

pub fn set_measured_exposure(&mut self, value: f32)

Sets the exposure value that should have been determined by average scene brightness. This may or may not affect Self::exposure() depending on the current graphics options.

Source

impl Camera

Values derived from the basic parameters, and functions for applying this camera’s characteristics to points and colors.

pub fn fov_y(&self) -> f64

Returns the field of view, expressed in degrees on the vertical axis (that is, the horizontal field of view depends on the viewport’s aspect ratio).

pub fn view_distance(&self) -> PositiveSign<f64>

Returns the view distance; the far plane of the view frustum, or the distance at which rendering may be truncated.

pub fn near_plane_distance(&self) -> PositiveSign<f64>

Returns the position of the near plane of the view frustum. This is not currently configurable.

pub fn projection_matrix(&self) -> Transform3D<f64, Eye, Ndc>

Returns a perspective projection matrix based on the configured FOV and view distance,

It maps coordinates in “eye” space into the Normalized Device Cooordinate space whose range is from -1 to 1 in X and Y, and 0 to 1 in Z. (This is DirectX and WebGPU style NDC, rather than OpenGL style which has a range of -1 to 1 in Z.)

pub fn view_matrix(&self) -> Transform3D<f64, Cube, Eye>

Returns a matrix which maps coordinates in world space to coordinates in eye space. It is the inverse of the current Camera::view_transform().

pub fn view_position(&self) -> Point3D<f64, Cube>

Returns the eye position in world coordinates, as set by Camera::set_view_transform().

pub fn project_ndc_into_world(&self, ndc: Point2D<f64, Ndc>) -> Ray

Converts a screen position in normalized device coordinates (as produced by Viewport::normalize_nominal_point()) into a ray in world space. Uses the view transformation given by set_view_transform.

The input coordinates should be within the range -1 to 1, inclusive. If they are not, the result may be a ray whose components are NaN.

The ray’s origin’s distance along the view direction axis is equal to Camera::near_plane_distance(). The ray’s Ray::unit_endpoint() along the view direction axis is equal to Camera::view_distance().

pub fn view_direction_mask(&self) -> OctantMask

Returns an OctantMask which includes all directions (in world space) visible in images rendered as specified by this camera.

This information may be used as a fast initial culling step, avoiding iterating over content behind the camera.

pub fn aab_in_view(&self, aab: Aab) -> bool

Determine whether the given Aab is visible in this projection+view.

pub fn exposure(&self) -> PositiveSign<f32>

Returns the current exposure value for scaling luminance.

Renderers should use this value, not the fixed exposure value in the GraphicsOptions. It may or may not be equal to the last set_measured_exposure(), depending on the graphics options.

pub fn post_process_color(&self, color: Rgba) -> Rgba

Apply postprocessing steps determined by this camera to convert a HDR “scene” color into a SDR “image” color. Specifically:

  1. Multiply the input by this camera’s exposure() value.
  2. Apply the tone mapping operator specified in Camera::options().