GraphicsOptions

Struct GraphicsOptions 

#[non_exhaustive]
pub struct GraphicsOptions {
Show 20 fields pub render_method: RenderMethod, pub fog: FogOption, pub fov_y: PositiveSign<f64>, pub tone_mapping: ToneMappingOperator, pub maximum_intensity: PositiveSign<f32>, pub exposure: ExposureOption, pub bloom_intensity: ZeroOne<f32>, pub view_distance: PositiveSign<f64>, pub lighting_display: LightingOption, pub transparency: TransparencyOption, pub show_ui: bool, pub antialiasing: AntialiasingOption, pub debug_info_text: bool, pub debug_info_text_contents: ShowStatus, pub debug_behaviors: bool, pub debug_chunk_boxes: bool, pub debug_collision_boxes: bool, pub debug_light_rays_at_cursor: bool, pub debug_pixel_cost: bool, pub debug_reduce_view_frustum: bool,
}
Options for controlling rendering (not affecting gameplay except informationally).

Some options may be ignored by some renderers, such as when they request a particular implementation approach or debug visualization. Renderers should make an effort to report such failings, such as via the all_is_cubes_render::Flaws type.

Serialization stability warning

This type implements [serde::Serialize] and [serde::Deserialize], but serialization support is still experimental (as is the game data model in general). We do not guarantee that future versions of all-is-cubes will be able to deserialize data which is serialized by this version.

Additionally, the serialization schema is designed with serde_json in mind. It is not guaranteed that using a different data format crate, which may use a different subset of the information exposed via [serde::Serialize], will produce stable results.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
render_method: RenderMethod

Overall rendering technique to use.

May be ignored if the method requested is not supported in the current environment.

fog: FogOption

Whether and how to draw fog obscuring the view distance limit.

TODO: Implement fog in raytracer.

fov_y: PositiveSign<f64>

Field of view, in degrees from top to bottom edge of the viewport.

Values ≥ 180° are ignored.

tone_mapping: ToneMappingOperator

Method to use to remap colors to fit within the displayable range.

In order for tone mapping to take effect, maximum_intensity must be set to an appropriate finite value.

maximum_intensity: PositiveSign<f32>

Maximum value to allow in the output image’s color channels.

  • If the output format/device supports HDR (high dynamic range; color channel values greater than 1.0), this should be set to the maximum representable (or desired) value.
  • If the output format is HDR and no specific limit is known or desired, use ∞. Note that this disables tone mapping.
  • If the output format is not HDR (SDR), use 1.0.
  • If no information is available, use ∞.

The chosen tone_mapping will use this information to map to the available range.

The default value is ∞.

exposure: ExposureOption

“Camera exposure” value: a scaling factor from scene luminance to displayed luminance. Note that the exact interpretation of this depends on the chosen tone_mapping.

bloom_intensity: ZeroOne<f32>

Proportion of bloom (blurred image) to mix into the original image. 0.0 is no bloom and 1.0 is no original image.

view_distance: PositiveSign<f64>

Distance, in unit cubes, from the camera to the farthest visible point. TODO: Implement view distance limit (and fog) in raytracer. TODO: make deserialization not break on infinity

lighting_display: LightingOption

Style in which to draw the lighting of Spaces. This does not affect the computation of lighting.

transparency: TransparencyOption

Method/fidelity to use for transparency.

show_ui: bool

Whether to show the HUD or other UI elements.

This does not affect UI state or clickability; it purely controls display. It is intended for the purpose of asking a renderer to produce an image of the scene without any UI.

The cursor is not currently considered part of the UI. This may be revisited later. The “info text” is controlled separately by debug_info_text.

antialiasing: AntialiasingOption

Whether to apply antialiasing techniques.

debug_info_text: bool

Draw text overlay showing debug information.

debug_info_text_contents: ShowStatus

What information should be displayed in debug_info_text.

debug_behaviors: bool

Draw boxes around Behaviors attached to parts of Spaces. This may also eventually include further in-world diagnostic information.

debug_chunk_boxes: bool

Draw boxes around chunk borders and some debug info.

debug_collision_boxes: bool

Draw collision boxes for some objects.

debug_light_rays_at_cursor: bool

Draw the light rays that contribute to the selected block.

debug_pixel_cost: bool

Visualize the cost of rendering each pixel, rather than the color of the scene.

Note that the current implementations of this in All is Cubes’ standard renderers do not measure actual execution cost, but quantities correlated with it. The color channels are used as follows:

  • In the raytracer,
    • Red-yellow: number of steps taken
    • Blue: original scene luminance
  • In the GPU mesh renderer:
    • Red: number of opaque fragment shader executions
    • Green: number of transparent fragment shader executions
    • Blue: number of triangles rasterized, including ones discarded by depth test
debug_reduce_view_frustum: bool

Causes [Camera] to compute a falsified view frustum which is 1/2 the width and height it should be.

This may be used to visualize the effect of frustum culling that is performed via [Camera::aab_in_view()].

Implementations

Source

impl GraphicsOptions

pub const UNALTERED_COLORS: GraphicsOptions

A set of graphics options which differs from GraphicsOptions::default() in that it disables all operations which change colors away from their obvious values; that is, the Rgba colors you get from a rendering will be identical (except for quantization error and background colors) to the Rgba colors in the depicted Atoms.

Future versions may set other options as necessary to maintain the intended property.

pub fn repair(self) -> GraphicsOptions

Constrain fields to valid/practical values.