Layers

Struct Layers 

pub struct Layers<T> {
    pub world: T,
    pub ui: T,
}
A collection of values associated with each of the layers of graphics that is normally drawn (HUD on top of world, currently) by HeadlessRenderer or other renderers.

Fields

world: T

The game world.

ui: T

The user interface, or HUD, drawn in front of the world.

Implementations

Source

impl<T> Layers<T>

pub fn splat(value: T) -> Self
where T: Clone,

Clone the given value for each layer.