#[non_exhaustive]pub enum Exception {
EnterSpace,
Sky,
Incomplete,
Paint,
}Expand description
Component of Hit indicating a situation other than an ordinary interaction of the ray
with a block in the space.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EnterSpace
The ray entered the bounds of the space (or started inside it). This may be used to notice whether or not a ray intersected the space at all, even if it hit no blocks.
Sky
The ray exited the space and is considered to have hit the sky.
Incomplete
For external reasons such as computational limits, the trace is being terminated and the the result will be incomplete.
Paint
Result of calling Accumulate::paint().