ColorBuf

Struct ColorBuf 

pub struct ColorBuf { /* private fields */ }
Implements Accumulate for RGB(A) color with f32 components, and conversion to Rgba.

In addition to its use in constructing images, this type is also used as an intermediate format for surface colors presented to any other Accumulate implementation.

Implementations

Source

impl ColorBuf

pub fn opacity_category(self) -> OpacityCategory

Returns the opacity of the contents of this buffer.