Hit

Struct Hit 

#[non_exhaustive]
pub struct Hit<'d, D> { pub exception: Option<Exception>, pub surface: ColorBuf, pub t_distance: Option<f64>, pub block: &'d D, pub position: Option<Position>, }
Data passed by the raytracer to Accumulate::add() implementations.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
exception: Option<Exception>

If Some, indicates that this hit denotes an exceptional situation rather than an ordinary interaction of the ray with a block in the space.

surface: ColorBuf

Contains the opacity/transmittance and the light output of the encountered surface, in the direction towards the camera.

This may also represent the ray traversing a thickness of transparent material when volume rendering is enabled, but it should be treated the same regardless.

t_distance: Option<f64>

Distance along the ray at which the encountered surface was intersected.

This distance is in units of the length of the original ray’s direction vector. Therefore, when forming an image, whether this value is Euclidean distance from the camera, or distance along the Z axis, depends on whether the rays are constructed with a constant length or a constant Z component.

It is None when the event creating this hit does not correspond to a single point in physical space, such as error indicators or 2D overlays.

block: &'d D

RtBlockData value for the block this surface or volume is part of.

position: Option<Position>

Which cube and voxel of the space the encountered surface belongs to, or None if this is a special case without a definite position such as the sky or an error report.

If a position in continuous space is desired, use t_distance and the original ray to reconstruct it instead.

Implementations

Source

impl<'d, D> Hit<'d, D>

pub fn map_block_data<D2>(self, f: impl Fn(&D) -> &D2) -> Hit<'d, D2>