#[non_exhaustive]pub struct RtOptionsRef<'a, C> {
pub graphics_options: &'a GraphicsOptions,
pub custom_options: &'a C,
}Expand description
Borrowed data which may be used to customize the result of raytracing.
This is provided by the raytracer to implementations of RtBlockData and Accumulate.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.graphics_options: &'a GraphicsOptionscustom_options: &'a CArbitrary data for the RtBlockData in use.