Struct all_is_cubes_render::Flaws
source · pub struct Flaws(/* private fields */);Expand description
Deficiencies of a rendering.
This type describes the ways in which a rendered image could fail to accurately
represent the scene, or fail to comply with requested GraphicsOptions.
It is a bitflags generated bit-flag type. Note: We make no guarantees that
the numeric value of flags will stay the same across versions; please treat this
as a set of named values only.
The empty set means no flaws are present.
Implementations
sourceimpl Flaws
impl Flaws
sourcepub const UNFINISHED: Self = _
pub const UNFINISHED: Self = _
The rendering is incomplete due to the renderer not having had enough time to finish initialization or catch up to changes.
sourcepub const NO_ANTIALIASING: Self = _
pub const NO_ANTIALIASING: Self = _
Antialiasing has not been used, despite being requested by the graphics options.
sourcepub const NO_BLOOM: Self = _
pub const NO_BLOOM: Self = _
Bloom has not been rendered, despite being requested by the graphics options.
sourcepub const NO_FOG: Self = _
pub const NO_FOG: Self = _
View-distance fog has not been rendered, despite being requested by the graphics options.
This does not refer to explicitly semitransparent objects within the scene.
sourcepub const MISSING_TEXTURES: Self = _
pub const MISSING_TEXTURES: Self = _
Surfaces that should have textures rather than a solid color don’t.
sourceimpl Flaws
impl Flaws
sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
sourceimpl Flaws
impl Flaws
sourcepub const fn iter(&self) -> Iter<Flaws>
pub const fn iter(&self) -> Iter<Flaws>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
sourcepub const fn iter_names(&self) -> IterNames<Flaws>
pub const fn iter_names(&self) -> IterNames<Flaws>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.