#[non_exhaustive]pub enum ToneMappingOperator {
Clamp,
Reinhard,
}Expand description
Choices for GraphicsOptions::tone_mapping.
Serialization stability warning
This type implements [serde::Serialize] and [serde::Deserialize], but serialization
support is still experimental (as is the game data model in general). We do not guarantee that future versions of all-is-cubes
will be able to deserialize data which is serialized by this version.
Additionally, the serialization schema is designed with serde_json in mind. It is not
guaranteed that using a different data format crate, which may use a different subset of
the information exposed via [serde::Serialize], will produce stable results.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Clamp
Limit values above the maximum (or below zero) to lie within that range.
This is the trivial tone mapping operation, and most “correct” for colors which do lie within the range, but will cause overly bright colors to change hue (as the RGB components are clamped independently).
Reinhard
TODO: As currently implemented this is an inadequate placeholder which is overly dark.
Implementations