#[non_exhaustive]pub struct Position {
pub cube: Cube,
pub resolution: Resolution,
pub voxel: Cube,
pub face: Face7,
}Expand description
Data about where a ray struck a voxel; part of Hit.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cube: CubeThe cube in the Space containing the block whose surface was hit.
resolution: ResolutionThe voxel resolution of the block.
voxel: CubeThe voxel within the block.
face: Face7The surface normal of the hit surface, or Face7::Within if the ray started inside this
voxel.